==> zio-aws-ec2_2.12-5.17.169.1-sources.jar: zio/aws/ec2/model/InstanceBlockDeviceMappingSpecification.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InstanceBlockDeviceMappingSpecification(
    deviceName: Optional[String] = Optional.Absent,
    ebs: Optional[zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification] =
      Optional.Absent,
    noDevice: Optional[String] = Optional.Absent,
    virtualName: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification = {
    import InstanceBlockDeviceMappingSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
      .builder()
      .optionallyWith(deviceName.map(value => value: java.lang.String))(
        _.deviceName
      )
      .optionallyWith(ebs.map(value => value.buildAwsValue()))(_.ebs)
      .optionallyWith(noDevice.map(value => value: java.lang.String))(
        _.noDevice
      )
      .optionallyWith(virtualName.map(value => value: java.lang.String))(
        _.virtualName
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification.ReadOnly =
    zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification
      .wrap(buildAwsValue())
}
object InstanceBlockDeviceMappingSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification =
      zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification(
        deviceName.map(value => value),
        ebs.map(value => value.asEditable),
        noDevice.map(value => value),
        virtualName.map(value => value)
      )
    def deviceName: Optional[String]
    def ebs: Optional[
      zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.ReadOnly
    ]
    def noDevice: Optional[String]
    def virtualName: Optional[String]
    def getDeviceName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("deviceName", deviceName)
    def getEbs: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.ReadOnly
    ] = AwsError.unwrapOptionField("ebs", ebs)
    def getNoDevice: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("noDevice", noDevice)
    def getVirtualName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("virtualName", virtualName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
  ) extends zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification.ReadOnly {
    override val deviceName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceName())
      .map(value => value: String)
    override val ebs: Optional[
      zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.ebs())
      .map(value =>
        zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.wrap(value)
      )
    override val noDevice: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.noDevice())
      .map(value => value: String)
    override val virtualName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.virtualName())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
  ): zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.155.1-sources.jar: zio/aws/ec2/model/InstanceBlockDeviceMappingSpecification.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InstanceBlockDeviceMappingSpecification(
    deviceName: Option[String] = None,
    ebs: Option[zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification] = None,
    noDevice: Option[String] = None,
    virtualName: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification = {
    import InstanceBlockDeviceMappingSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
      .builder()
      .optionallyWith(deviceName.map(value => value: java.lang.String))(
        _.deviceName
      )
      .optionallyWith(ebs.map(value => value.buildAwsValue()))(_.ebs)
      .optionallyWith(noDevice.map(value => value: java.lang.String))(
        _.noDevice
      )
      .optionallyWith(virtualName.map(value => value: java.lang.String))(
        _.virtualName
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification.ReadOnly =
    zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification
      .wrap(buildAwsValue())
}
object InstanceBlockDeviceMappingSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification =
      zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification(
        deviceName.map(value => value),
        ebs.map(value => value.asEditable),
        noDevice.map(value => value),
        virtualName.map(value => value)
      )
    def deviceName: Option[String]
    def ebs
        : Option[zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.ReadOnly]
    def noDevice: Option[String]
    def virtualName: Option[String]
    def getDeviceName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("deviceName", deviceName)
    def getEbs: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.ReadOnly
    ] = AwsError.unwrapOptionField("ebs", ebs)
    def getNoDevice: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("noDevice", noDevice)
    def getVirtualName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("virtualName", virtualName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
  ) extends zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification.ReadOnly {
    override val deviceName: Option[String] =
      scala.Option(impl.deviceName()).map(value => value: String)
    override val ebs: Option[
      zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.ReadOnly
    ] = scala
      .Option(impl.ebs())
      .map(value =>
        zio.aws.ec2.model.EbsInstanceBlockDeviceSpecification.wrap(value)
      )
    override val noDevice: Option[String] =
      scala.Option(impl.noDevice()).map(value => value: String)
    override val virtualName: Option[String] =
      scala.Option(impl.virtualName()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceBlockDeviceMappingSpecification
  ): zio.aws.ec2.model.InstanceBlockDeviceMappingSpecification.ReadOnly =
    new Wrapper(impl)
}
